@@ -1,6 +1,8 @@
 """Re-usable layout snippets."""
 from ezcharts.layout.snippets.banner import Banner   # noqa: F401,F403
 from ezcharts.layout.snippets.grid import Grid   # noqa: F401,F403
+from ezcharts.layout.snippets.offcanvas import OffCanvas   # noqa: F401,F403
+from ezcharts.layout.snippets.progress import Progress   # noqa: F401,F403
 from ezcharts.layout.snippets.stats import Stats  # noqa: F401,F403
 from ezcharts.layout.snippets.table import DataTable   # noqa: F401,F403
 from ezcharts.layout.snippets.tabs import Tabs   # noqa: F401,F403
